@@ -4,13 +4,17 @@
 Autoshape-related objects such as Shape and Adjustment.
 """
 
+from __future__ import absolute_import, print_function
+
 from numbers import Number
+from warnings import warn
 
 from ..dml.fill import FillFormat
 from ..dml.line import LineFormat
 from ..enum.shapes import MSO_AUTO_SHAPE_TYPE, MSO_SHAPE_TYPE
 from .shape import BaseShape
 from ..spec import autoshape_types
+from ..text import TextFrame
 from ..util import lazyproperty
 
 
@@ -311,6 +315,26 @@ class Shape(BaseShape):
         """
         return self._sp.get_or_add_ln()
 
+    @property
+    def has_text_frame(self):
+        """
+        |True| if this shape can contain text. Always |True| for an
+        AutoShape.
+        """
+        return True
+
+    @property
+    def has_textframe(self):
+        """
+        Deprecated. Use :attr:`has_text_frame` property instead.
+        """
+        msg = (
+            'Shape.has_textframe property is deprecated. Use .has_text_frame'
+            ' instead.'
+        )
+        warn(msg, UserWarning, stacklevel=2)
+        return self.has_text_frame
+
     @lazyproperty
     def line(self):
         """
@@ -341,3 +365,45 @@ class Shape(BaseShape):
             return MSO_SHAPE_TYPE.TEXT_BOX
         msg = 'Shape instance of unrecognized shape type'
         raise NotImplementedError(msg)
+
+    @property
+    def text(self):
+        """
+        Read/write. All the text in this shape as a single string. A line
+        feed character ('\\\\n') appears in the string for each paragraph and
+        line break in the shape, except the last paragraph. A shape
+        containing a single paragraph with no line breaks will produce
+        a string having no line feed characters. Assigning a string to this
+        property replaces all text in the shape with a single paragraph
+        containing the assigned text. The assigned value can be a 7-bit ASCII
+        string, a UTF-8 encoded 8-bit string, or unicode. String values are
+        converted to unicode assuming UTF-8 encoding. Each line feed
+        character in an assigned string is translated into a line break
+        within the single resulting paragraph.
+        """
+        return self.text_frame.text
+
+    @text.setter
+    def text(self, text):
+        self.text_frame.text = text
+
+    @property
+    def text_frame(self):
+        """
+        |TextFrame| instance for this shape, containing the text of the shape
+        and providing access to text formatting properties.
+        """
+        txBody = self._element.get_or_add_txBody()
+        return TextFrame(txBody, self)
+
+    @property
+    def textframe(self):
+        """
+        Deprecated. Use :attr:`text_frame` property instead.
+        """
+        msg = (
+            'Shape.textframe property is deprecated. Use .has_text_frame ins'
+            'tead.'
+        )
+        warn(msg, UserWarning, stacklevel=2)
+        return self.text_frame
